.. _spkg_ninja_build:

ninja_build: A build system with a focus on speed
=================================================

Description
-----------

Ninja is a small build system with a focus on speed.

License
-------

Apache License 2.0


Upstream Contact
----------------

https://ninja-build.org/



Type
----

standard


Dependencies
------------

- $(PYTHON)

Version Information
-------------------

package-version.txt::

    1.13.1

See https://repology.org/project/ninja/versions

Installation commands
---------------------

.. tab:: Sage distribution:

   .. CODE-BLOCK:: bash

       $ sage -i ninja_build

.. tab:: Arch Linux:

   .. CODE-BLOCK:: bash

       $ sudo pacman -S ninja

.. tab:: conda-forge:

   .. CODE-BLOCK:: bash

       $ conda install ninja

.. tab:: Debian/Ubuntu:

   .. CODE-BLOCK:: bash

       $ sudo apt-get install ninja-build

.. tab:: Fedora/Redhat/CentOS:

   .. CODE-BLOCK:: bash

       $ sudo dnf install ninja-build

.. tab:: FreeBSD:

   .. CODE-BLOCK:: bash

       $ sudo pkg install devel/ninja

.. tab:: Gentoo Linux:

   .. CODE-BLOCK:: bash

       $ sudo emerge dev-build/ninja

.. tab:: Homebrew:

   .. CODE-BLOCK:: bash

       $ brew install ninja

.. tab:: MacPorts:

   .. CODE-BLOCK:: bash

       $ sudo port install ninja

.. tab:: mingw-w64:

   .. CODE-BLOCK:: bash

       $ sudo pacman -S ${MINGW_PACKAGE_PREFIX}-ninja

.. tab:: Nixpkgs:

   .. CODE-BLOCK:: bash

       $ nix-env -f \'\<nixpkgs\>\' --install --attr ninja

.. tab:: openSUSE:

   .. CODE-BLOCK:: bash

       $ sudo zypper install ninja

.. tab:: Void Linux:

   .. CODE-BLOCK:: bash

       $ sudo xbps-install ninja


If the system package is installed, ``./configure`` will check if it can be used.
